#!/bin/bash
#
# Copyright 2013 Stefan Brenner, Sven Schober
#
# This file is part of DAE.
#
# DAE is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# DAE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DAE.  If not, see <http://www.gnu.org/licenses/>.
#

### global config
DIR="results"
EXE="./master.sh"
PLOT="./gnuplot.sh"
DEF_ITER=10
CALC=0

mkdir -p $DIR

### execution

# numbers 0.0 0.1 ... 1.0
num=$(awk 'BEGIN{for(i=0;i<=1;i+=0.1)print i}' | sed 's/,/./')

# FIGURE: dsl symratio

scripts/figure-dsl-symratio.sh

exit;
# FIGURE: amount of measurements with various symratio

sequoia="$DIR/dslconnections-measurements-sequoia-$DEF_ITER-symratio${symratio}.dat"
song="$DIR/dslconnections-measurements-song-$DEF_ITER-symratio${symratio}.dat"
dae="$DIR/dslconnections-measurements-dae-$DEF_ITER-symratio${symratio}.dat"
figure="dslconnections-measurements-$DEF_ITER-symratio.eps"

rm $sequoia
rm $song
rm $dae

touch $sequoia
touch $song
touch $dae

for symratio in $num; do
	$EXE -to dslconnections -avgmeas -tr sequoia -i $DEF_ITER -symratio $symratio >> $sequoia
	$EXE -to dslconnections -avgmeas -tr song    -i $DEF_ITER -symratio $symratio >> $song
	$EXE -to dslconnections -avgmeas -tr dae     -i $DEF_ITER -symratio $symratio >> $dae
done

./gnuplot.sh $figure "Symmetry ratio" "Measurements" 0 1 0 5 0 0 \
	Sequoia $sequoia \
	Song 	$song \
	DAE 	$dae

# FIGURE: all trees embedding planetlab (rel error)

sequoia="$DIR/planetlab-relerror-sequoia.dat"
song="$DIR/planetlab-relerror-song.dat"
dae="$DIR/planetlab-relerror-dae.dat"
figure="planetlab-relerror.eps"

rm $sequoia
rm $song
rm $dae

touch $sequoia
touch $song
touch $dae

$EXE -to planetlab -tr sequoia -cdf >> $sequoia
$EXE -to planetlab -tr song    -cdf >> $song
$EXE -to planetlab -tr dae     -cdf >> $dae

./gnuplot.sh $figure "Rel. prediction error" "Probability" 0 10 0 1 0 0 \
	Sequoia $sequoia \
	Song 	$song \
	DAE 	$dae


# FIGURE: all trees embedding planetlab (measurement count)

sequoia="$DIR/planetlab-measurements-$DEF_ITER-sequoia.dat"
song="$DIR/planetlab-measurements-$DEF_ITER-song.dat"
dae="$DIR/planetlab-measurements-$DEF_ITER-dae.dat"

rm $sequoia
rm $song
rm $dae

touch $sequoia
touch $song
touch $dae

$EXE -to planetlab -tr sequoia -i $DEF_ITER -avgmeas >> $sequoia
$EXE -to planetlab -tr song    -i $DEF_ITER -avgmeas >> $song
$EXE -to planetlab -tr dae     -i $DEF_ITER -avgmeas >> $dae
