/**
 *
 * Copyright 2013 Stefan Brenner, Sven Schober
 *
 * This file is part of DAE.
 *
 * DAE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DAE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DAE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package sequoia.topology;

import java.util.HashMap;
import java.util.Map;

/**
 * Topology type based on defining the downstream and upstream bandwidth of
 * individual hosts in order to generate a complete matrix of path bandwidth
 * values.
 * 
 * @author stefan
 * 
 */
abstract public class HostConnectionTopology extends Topology {

	private static int MINVALUE = 1;

	protected Map<String, Integer> upstreamBandwidth = new HashMap<String, Integer>();
	protected Map<String, Integer> downstreamBandwidth = new HashMap<String, Integer>();

	/**
	 * generate complete graph
	 */
	protected void genTable() {
		for (String a : _hosts) {
			for (String b : _hosts) {
				if (a.equals(b))
					continue;
				// bandwidth(a,b) = min(upstream(a), downstream(b))
				int val = upstreamBandwidth.get(a) > downstreamBandwidth.get(b) ? downstreamBandwidth.get(b) : upstreamBandwidth.get(a);
				addLinkBandwidth(a, b, val);
			}
		}
	}

	/**
	 * adds a new host's upstream downstream values to the list of hosts
	 */
	protected void addHostBandwLimits(String hostname, int bwDown, int bwUp) {
		rememberHostname(hostname);

		bwDown = bwDown > MINVALUE ? bwDown : MINVALUE;
		bwUp = bwUp > MINVALUE ? bwUp : MINVALUE;

		downstreamBandwidth.put(hostname, bwDown);
		upstreamBandwidth.put(hostname, bwUp);
	}

}
